import cpapi = require('@aws-cdk/aws-codepipeline-api');
import events = require('@aws-cdk/aws-events');
import { CfnPipeline } from './codepipeline.generated';
import { Pipeline, StageProps } from './pipeline';
/**
 * A Stage in a Pipeline.
 *
 * Stages are added to a Pipeline by calling {@link Pipeline#addStage},
 * which returns an instance of {@link cpapi.IStage}.
 *
 * This class is private to the CodePipeline module.
 */
export declare class Stage implements cpapi.IStage {
    /**
     * The Pipeline this Stage is a part of.
     */
    readonly pipeline: cpapi.IPipeline;
    readonly stageName: string;
    private readonly scope;
    private readonly _actions;
    /**
     * Create a new Stage.
     */
    constructor(props: StageProps, pipeline: Pipeline);
    /**
     * Get a duplicate of this stage's list of actions.
     */
    readonly actions: cpapi.Action[];
    render(): CfnPipeline.StageDeclarationProperty;
    addAction(action: cpapi.Action): void;
    onStateChange(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    protected validate(): string[];
    private attachActionToPipeline;
    private renderAction;
    private validateHasActions;
}
